package cn.com.countrygarden.bi.main.dao.experience;

import cn.com.countrygarden.bi.main.dto.experience.TygGzhUserInfoDto;
import cn.com.countrygarden.bi.main.dto.experience.WcxExperContentDto;
import cn.com.countrygarden.bi.main.dto.experience.WcxPublishFileDto;
import cn.com.countrygarden.bi.main.model.experience.WcxEmployeesManage;
import cn.com.countrygarden.bi.main.model.experience.WcxEmployeesManageDto;
import cn.com.countrygarden.bi.main.model.experience.WcxPublishMessage;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.springframework.web.bind.annotation.PostMapping;

import java.util.List;
import java.util.Map;

@Mapper
public interface WcxExperienceMapper {


    List<WcxEmployeesManage> list(Map<String,Object> params);

    List<WcxEmployeesManageDto> list2(Map<String,Object> params);
    int count(Map<String,Object> params);

    WcxEmployeesManage queryById(@Param("id") Long id);

    List<WcxEmployeesManage> queryByPhone(@Param("phone") String phone,@Param("identification") String identification);

    int delete(@Param("id") Long id);

    int setEnable(@Param("enable") String enable,@Param("id") Long id);

    int save(WcxEmployeesManage manage);

    int update(WcxEmployeesManage manage);

    int batchSave(List<WcxEmployeesManage> manages);

    int batchSaveCustomer(List<WcxEmployeesManage> manages);

    List<WcxExperContentDto> contentList(Map<String,Object> params);

    List<WcxExperContentDto> exportList(Map<String,Object> params);

    int countContent(Map<String,Object> params);

    int score(WcxExperContentDto dto);

    int deleteContent(WcxExperContentDto dto);

    List<WcxPublishFileDto> queryPublishFiles(WcxExperContentDto dto);


    List<WcxPublishMessage> queryPublishList(@Param("phone") String phone);

    List<WcxEmployeesManage> selectByByOpenId(@Param("openId")String openId);

    void updateAccessToken(WcxEmployeesManage wcxEmployeesManage);

    List<WcxEmployeesManage> selectByPhone(@Param("phone")String phone);

    List<WcxEmployeesManage> selectByIds(@Param("ids")String[] split, @Param("page") int page,@Param("size")  int size);

    int selectCountByIds(@Param("ids")String[] split);

    List<WcxEmployeesManage> selectByTygGzhUserInfoDto(TygGzhUserInfoDto tygGzhUserInfoDto1);

    int selectByTygGzhUserInfoDtoCount(TygGzhUserInfoDto tygGzhUserInfoDto1);

    List<WcxEmployeesManage> selectAllByIds(@Param("ids")List<String> asList);

    List<WcxPublishFileDto> queryPublishFile(String publishNo);

    List<WcxEmployeesManage> selectByAccessToken(String accessToken);

    List<WcxEmployeesManage> selectAllOrByPhoneBy0(@Param("identification") String id);

    String selectMax(@Param("identification") String id);

    void updateTygCertificateNumberByPhoen(WcxEmployeesManage wcxEmployeesManage);

    List<WcxEmployeesManage> selectByPhoneAndIdentification(@Param("phone") String phone, @Param("identification") String s);

    int selectSourceById(Long id);

    int selectCountSourceById(Long id);

    List<WcxEmployeesManage> queryByPhoneOrderByLastUpdate(@Param("phone")String phone,@Param("identification") String s);
}
